@@ -11,7 +11,6 @@
 #include "krichtextedit_p.h"
 
 // KDE includes
-#include <KColorScheme>
 #include <KFontAction>
 #include <KFontSizeAction>
 #include <KLocalizedString>
@@ -541,8 +540,6 @@ void KRichTextWidgetPrivate::_k_setHeadingLevel(int level)
 
 void KRichTextWidgetPrivate::updateCharFormatActions(const QTextCharFormat &format)
 {
-    Q_Q(KRichTextWidget);
-
     QFont f = format.font();
 
     if (richTextSupport & KRichTextWidget::SupportFontFamily) {
@@ -634,7 +631,7 @@ void KRichTextWidgetPrivate::_k_setTextForegroundColor()
     Q_Q(KRichTextWidget);
 
     const QColor currentColor = q->textColor();
-    const QColor defaultColor = KColorScheme(QPalette::Active, KColorScheme::View).foreground().color();
+    const QColor defaultColor = q->palette().color(QPalette::Active, QPalette::Text);
 
     const QColor selectedColor = QColorDialog::getColor(currentColor.isValid() ? currentColor : defaultColor, q);
 
@@ -651,7 +648,7 @@ void KRichTextWidgetPrivate::_k_setTextBackgroundColor()
 
     QTextCharFormat fmt = q->textCursor().charFormat();
     const QColor currentColor = fmt.background().color();
-    const QColor defaultColor = KColorScheme(QPalette::Active, KColorScheme::View).foreground().color();
+    const QColor defaultColor = q->palette().color(QPalette::Active, QPalette::Text);
 
     const QColor selectedColor = QColorDialog::getColor(currentColor.isValid() ? currentColor : defaultColor, q);
 
